##
##  vifm.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2025 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package version
%define       V_opkg   0.14
%define       V_dist   0.14-beta
%define       V_subdir 0.14-beta

#   package information
Name:         vifm
Summary:      Vi File Manager
URL:          http://vifm.info/
Vendor:       Ken Steen et al.
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Terminal
License:      GPL
Version:      %{V_opkg}
Release:      20250223

#   list of sources
Source0:      http://downloads.sourceforge.net/vifm/vifm-%{V_dist}.tar.bz2
Source1:      vifmrc

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101
PreReq:       OpenPKG, openpkg >= 20160101
BuildPreReq:  file, ncurses, ncurses::with_widechar = yes
PreReq:       file, ncurses, ncurses::with_widechar = yes

%description
    Vifm is a ncurses based file manager with vi like keybindings. If
    you use vi, vifm gives you complete keyboard control over your files
    without having to learn a new set of commands.

%track
    prog vifm = {
        version   = %{V_dist}
        url       = http://vifm.info/downloads.shtml
        regex     = vifm-(__VER__)\.tar\.bz2
    }

%prep
    %setup -q -n vifm-%{V_subdir}

%build
    #   configure program
    %{l_shtool} subst \
        -e 's;-Wall;;' \
        configure
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O}" \
    CPPFLAGS="%{l_cppflags ncurses .}" \
    LDFLAGS="%{l_ldflags}" \
    ./configure \
        --prefix=%{l_prefix} \
        --mandir=%{l_prefix}/man \
        --with-libmagic \
        --with-curses=%{l_prefix} \
        --with-curses-name=ncursesw \
        --disable-desktop-files \
        --without-gtk \
        --without-X11

    #   build program
    %{l_make} %{l_mflags -O}

%install
    #   install program
    %{l_make} %{l_mflags} install AM_MAKEFLAGS="DESTDIR=$RPM_BUILD_ROOT"

    #   install default configuration
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/etc/vifm
    %{l_shtool} install -c -m 644 %{l_value -s -a} \
        %{SOURCE vifmrc} $RPM_BUILD_ROOT%{l_prefix}/etc/vifm/

    #   strip down installation
    rm -f $RPM_BUILD_ROOT%{l_prefix}/share/vifm/vifmrc*
    rm -rf $RPM_BUILD_ROOT%{l_prefix}/share/applications
    rm -rf $RPM_BUILD_ROOT%{l_prefix}/share/doc
    rm -rf $RPM_BUILD_ROOT%{l_prefix}/share/pixmaps
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* >/dev/null 2>&1 || true

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} \
        '%config %{l_prefix}/etc/vifm/*'

%files -f files

%clean

